<template>
  <InfiniteLoading scrollViewClassName="common-infinite-scroll-list" v-bind="infiniteLoadingProps">
    <template #renderItem="{ item }">
      <OrderCard
        :title="item.orderName"
        :hireType="item.hireType"
        :hireNumber="item.hireNumber"
        :hireEndNumber="item.hireEndNumber"
        :ageStart="item.ageStart"
        :ageEnd="item.ageEnd"
        :provinceName="item.provinceName"
        :cityName="item.cityName"
        :orderSupplierRefundInfo="item.orderSupplierRefundInfo"
        :src="item.avatarUrl"
        :name="item.contact"
        :jobTitle="item.jobTitle"
        :time="item.lastShelfTime"
        :integratedSalary="item.integratedSalary"
        @click="handleClick(item)"
        :showActionBtn="false"
      >
      </OrderCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { useInfiniteLoading } from '@12333/hooks';
import * as orderServices from '@12333/services/api/Order';
import { OrderInputType, IndustryCategoryType } from '@12333/constants';
import { useAccessPersonalInfo, useCategoryMenu } from '@/hooks';
import { CategoryUtils } from '@12333/utils';
import Taro from '@tarojs/taro';

type Props = {
  userId?: string;
};

const props = withDefaults(defineProps<Props>(), {});

const queryState = reactive({
  categoryId: '',
  userId: props.userId,
});

const { ensureCategoryMenu, categoryMenuList: industryServicesCategoryList } = useCategoryMenu({
  type: IndustryCategoryType.IndustryServices,
});

onMounted(async () => {
  await ensureCategoryMenu();
  queryState.categoryId = industryServicesCategoryList.value.find((x) =>
    CategoryUtils.isIHasOrder(x.name)
  ).id;
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          { property: 'isRecommend', order: OrderInputType.Desc },
          { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
      categoryId: queryState.categoryId,
      userId: queryState.userId,
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
    enabled: computed(() => !!queryState.categoryId),
  }
);

function handleClick(item: API.FrontOrderList) {
  Taro.navigateTo({
    url: `${RouterPath.orderDetail}?id=${item.id}`,
  });
}
</script>
